Molecular
=========

.. toctree::
  :maxdepth: 1

  PositionedAtom <_autosummary/stko.PositionedAtom>
  dummy atom (Du) <_autosummary/stko.Du>
  MDAnalysis <_autosummary/stko.MDAnalysis>
  ZMatrix <_autosummary/stko.ZMatrix>
  MoleculeSplitter <_autosummary/stko.MoleculeSplitter>
  MoleculeTransformer <_autosummary/stko.MoleculeTransformer>
  Network <_autosummary/stko.Network>
  UnitCell <_autosummary/stko.UnitCell>
  TopologyExtractor <_autosummary/stko.TopologyExtractor>
  TopologyInfo <_autosummary/stko.TopologyInfo>
  Torsion <_autosummary/stko.Torsion>
  TorsionInfo <_autosummary/stko.TorsionInfo>
  ThreeSiteFG <_autosummary/stko.functional_groups.ThreeSiteFG>
  ThreeSiteFactory <_autosummary/stko.functional_groups.ThreeSiteFactory>
  DecomposeMOC <_autosummary/stko.molecule_analysis.DecomposeMOC>
  DitopicThreeSiteAnalyser <_autosummary/stko.molecule_analysis.DitopicThreeSiteAnalyser>
  ConstructedAnalyser <_autosummary/stko.molecule_analysis.ConstructedAnalyser>
  AlkyneAngle <_autosummary/stko.molecule_analysis.AlkyneAngle>
  X5Planarity <_autosummary/stko.molecule_analysis.X5Planarity>
  C5N1Planarity <_autosummary/stko.molecule_analysis.C5N1Planarity>
  C6Planarity <_autosummary/stko.molecule_analysis.C6Planarity>
  Subgroup <_autosummary/stko.molecule_analysis.Subgroup>
  SubgroupAnalyser <_autosummary/stko.molecule_analysis.SubgroupAnalyser>
